@@ -101,8 +101,8 @@ class RemoteArchive(object):
             heuristic=ExpiresAfter(seconds=5),
         ))
 
-    def _remote_file(self, url, basedir=None):
-        return RemoteFile(self.session, url, basedir)
+    def _remote_file(self, url):
+        return RemoteFile(self.session, url)
 
     def search(self, query, filtered=True):
         """Search for extension packages"""
